"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHighLight = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const getAllHighlights = async (page) => {
    // get wrapper element
    const container = await page.waitForSelector("#kp-notebook-annotations");
    // get all highlights in the container
    await page.waitForTimeout(10000);
    const allHighlights = await container?.$$(".a-spacing-base");
    if (!allHighlights) {
        return null;
    }
    let highlights = [];
    console.log(`Saving ${allHighlights.length} highlights`);
    for (const highlightDiv of allHighlights) {
        const header = await (await highlightDiv.$("#annotationHighlightHeader"))?.evaluate((el) => el.textContent);
        const pageNo = header?.split("|")[1]?.trim();
        // get content
        const highlight = await (await highlightDiv.$("#highlight"))?.evaluate((el) => el.textContent);
        highlights = [
            ...highlights,
            { pageNo: pageNo || "", highlight: highlight || "" },
        ];
    }
    return highlights;
};
const getHighLight = async (page) => {
    const allBooks = await page.$$("h2");
    let allHighlights = [];
    for (const book of allBooks) {
        await book.evaluate((el) => el.parentElement?.click());
        const title = await book.evaluate((el) => el.textContent);
        console.log(`Getting highlights for ${title}`);
        const highlights = await getAllHighlights(page);
        allHighlights = [
            ...allHighlights,
            {
                bookTitle: title || "",
                highlights,
            },
        ];
    }
    fs_extra_1.default.outputFileSync("./temp/highlights.json", JSON.stringify(allHighlights));
};
exports.getHighLight = getHighLight;
